***
To Create a **python3-videomass.deb** package for your Debian or Debian-based 
distribution, visit the [Package for Debian and derivatives](https://github.com/jeanslack/Videomass/wiki/Package-for-Debian-and-derivatives) Wiki page:
***
